/***************************************************************************
 * This file is part of the project AqFoxExt.                              *
 * AqFoxExt (c) by 2011 Martin Preuss, all rights reserved.                *
 *                                                                         *
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef FXX_APP_HPP
#define FXX_APP_HPP


#include <aqfoxext/aqfoxext.h>
#include <aqfoxext/FXXTrayApp.h>

#include <gwenhywfar/db.h>
#include <gwenhywfar/configmgr.h>


#define FXX_PM_LIBNAME       "aqfoxext"
#define FXX_PM_RESSOURCEDIR  "ressources"

class FXXIconDict;



class AQFOXEXT_API FXXApp: public FXXTrayApp {
  friend class FXXIconDict;

public:
  FXXApp(const FXString& name="AqFoxExt",
         const FXString& vendor="Aquamaniac");
  virtual ~FXXApp();

  virtual void init(int& argc, char** argv, bool connect=true);
  virtual void fini();

  GWEN_DB_NODE *getDialogConfig(const char *name);
  int setDialogConfig(const char *name, GWEN_DB_NODE *db);

  const FXSize &getSizeSmallIcons() const { return m_sizeSmallIcons;};
  const FXSize &getSizeMediumIcons() const { return m_sizeMediumIcons;};
  const FXSize &getSizeBigIcons() const { return m_sizeBigIcons;};

  FXColor getMarkColor1() const { return m_markColor1;};
  void setMarkColor1(FXColor c) { m_markColor1=c;};

  bool isRestartRequested() const { return m_restartRequested;};
  void setRestartRequested(bool b) { m_restartRequested=b;};

  /**
   * Returns the given icon.
   * The FXXApp object remains the owner of the object returned so you
   * MUST NOT free it.
   * If the icon could not be found an empty icon is returned instead so this
   * function should always return an icon.
   */
  virtual FXIcon *getIcon(const char *name);


  virtual GWEN_CONFIGMGR *getConfigManager()=0;


protected:
  FXIcon *getEmptyIcon();
  FXString getIconFilePath(const char *name);
  FXIcon *loadIconFile(const char *name);
  FXIcon *loadIcon(const char *name);


  FXSize m_sizeSmallIcons;
  FXSize m_sizeMediumIcons;
  FXSize m_sizeBigIcons;

  FXColor m_markColor1;

  bool m_restartRequested;

  FXIconSource *m_iconSource;
  FXXIconDict *m_iconDict;
  FXIcon *m_emptyIcon;
};



#endif

